FloatColor

Struct FloatColor 

pub struct FloatColor { /* private fields */ }

Implementations

Source

impl FloatColor

pub fn set_r(&mut self, new_value: f64)

Sets the red value of the color. Values range from 0.0 (no red) to 1.0 (fully red).

The provided color value is clamped between 0.0 and 1.0.

Panics

This function will panic if the provided argument is NaN.

Examples
let mut color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color.set_r(0.5);
assert_eq!(color.get_r(), 0.5);
let mut color_clamped_lower = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color_clamped_lower.set_r(-20.0);
assert_eq!(color_clamped_lower.get_r(), 0.0);
let mut color_clamped_upper = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color_clamped_upper.set_r(15.0);
assert_eq!(color_clamped_upper.get_r(), 1.0);

This example will panic:

let mut color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color.set_r(std::f64::NAN);
pub fn set_g(&mut self, new_value: f64)

Sets the green value of the color. Values range from 0.0 (no green) to 1.0 (fully green).

The provided color value is clamped between 0.0 and 1.0.

Panics

This function will panic if the provided argument is NaN.

Examples
let mut color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color.set_g(0.6);
assert_eq!(color.get_g(), 0.6);
let mut color_clamped_lower = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color_clamped_lower.set_g(-20.0);
assert_eq!(color_clamped_lower.get_g(), 0.0);
let mut color_clamped_upper = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color_clamped_upper.set_g(15.0);
assert_eq!(color_clamped_upper.get_g(), 1.0);

This example will panic:

let mut color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color.set_g(std::f64::NAN);
pub fn set_b(&mut self, new_value: f64)

Sets the blue value of the color. Values range from 0.0 (no blue) to 1.0 (fully blue).

The provided color value is clamped between 0.0 and 1.0.

Panics

This function will panic if the provided argument is NaN.

Examples
let mut color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color.set_b(0.7);
assert_eq!(color.get_b(), 0.7);
let mut color_clamped_lower = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color_clamped_lower.set_b(-20.0);
assert_eq!(color_clamped_lower.get_b(), 0.0);
let mut color_clamped_upper = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color_clamped_upper.set_b(15.0);
assert_eq!(color_clamped_upper.get_b(), 1.0);

This example will panic:

let mut color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color.set_b(std::f64::NAN);
pub fn set_a(&mut self, new_value: f64)

Sets the alpha (opacity) value of the color. Values range from 0.0 (fully transparent) to 1.0 (fully opaque).

The provided color value is clamped between 0.0 and 1.0.

Panics

This function will panic if the provided argument is NaN.

Examples
let mut color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color.set_a(0.8);
assert_eq!(color.get_a(), 0.8);
let mut color_clamped_lower = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color_clamped_lower.set_a(-20.0);
assert_eq!(color_clamped_lower.get_a(), 0.0);
let mut color_clamped_upper = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color_clamped_upper.set_a(15.0);
assert_eq!(color_clamped_upper.get_a(), 1.0);

This example will panic:

let mut color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
color.set_a(std::f64::NAN);
pub fn get_r(&self) -> f64

Returns the red value of the color. Values range from 0.0 (no red) to 1.0 (fully red).

Examples
let color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
assert_eq!(color.get_r(), 0.1);
pub fn get_g(&self) -> f64

Returns the green value of the color. Values range from 0.0 (no green) to 1.0 (fully green).

Examples
let color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
assert_eq!(color.get_g(), 0.2);
pub fn get_b(&self) -> f64

Returns the blue value of the color. Values range from 0.0 (no blue) to 1.0 (fully blue).

Examples
let color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
assert_eq!(color.get_b(), 0.3);
pub fn get_a(&self) -> f64

Returns the alpha (opacity) value of the color. Values range from 0.0 (fully transparent) to 1.0 (fully opaque).

Examples
let color = FloatColor::new(0.1, 0.2, 0.3, 0.4);
assert_eq!(color.get_a(), 0.4);
pub fn new(r: f64, g: f64, b: f64, a: f64) -> Self

Constructs a new FloatColor structure from four f64 values. The color values provided via arguments are clamped between 0.0 and 1.0.

Panics

This function will panic if any of the arguments is NaN.

Examples
let color1 = FloatColor::new(0.4, 0.0, -2.9, std::f64::NEG_INFINITY);
assert_eq!(color1.get_r(), 0.4);
assert_eq!(color1.get_g(), 0.0);
assert_eq!(color1.get_b(), 0.0);
assert_eq!(color1.get_a(), 0.0);

let color2 = FloatColor::new(0.6, 1.0, 2.9, std::f64::INFINITY);
assert_eq!(color2.get_r(), 0.6);
assert_eq!(color2.get_g(), 1.0);
assert_eq!(color2.get_b(), 1.0);
assert_eq!(color2.get_a(), 1.0);

These examples will panic:

FloatColor::new(std::f64::NAN, 0.2, 0.3, 0.4);
FloatColor::new(0.1, std::f64::NAN, 0.3, 0.4);
FloatColor::new(0.1, 0.2, std::f64::NAN, 0.4);
FloatColor::new(0.1, 0.2, 0.3, std::f64::NAN);